Worker: Rename worker components to clarify what they work for

(1) It sounds like WorkerGlobalScopeProxy is the base class of
ServiceWorkerGlobalScopeProxy, but it is not true. WorkerGlobalScopeProxy works
for in-process workers, namely, DedicatedWorker and CompositorWorker.
This patch renames them as follows:

  WorkerGlobalScopeProxy => InProcessWorkerGlobalScopeProxy
  WorkerMessagingProxy => InProcessWorkerMessagingProxy

(2) WorkerGlobalScopeProxyProvider provides a proxy for DedicatedWorker, so it
should be prefixed with "Dedicated":

  WorkerGlobalScopeProxyProvider => DedicatedWorkerGlobalScopeProxyProvider
  WorkerGlobalScopeProxyProviderImpl => DedicatedWorkerGlobalScopeProxyProviderImpl

BUG=603785

Review URL: https://codereview.chromium.org/1888703002

Cr-Commit-Position: refs/heads/master@{#388166}
diff --git a/third_party/WebKit/Source/core/core.gypi b/third_party/WebKit/Source/core/core.gypi
index c99940b..993c02d 100644
--- a/third_party/WebKit/Source/core/core.gypi
+++ b/third_party/WebKit/Source/core/core.gypi
@@ -2227,12 +2227,17 @@
             'workers/AbstractWorker.h',
             'workers/DedicatedWorkerGlobalScope.cpp',
             'workers/DedicatedWorkerGlobalScope.h',
+            'workers/DedicatedWorkerGlobalScopeProxyProvider.cpp',
+            'workers/DedicatedWorkerGlobalScopeProxyProvider.h',
             'workers/DedicatedWorkerMessagingProxy.cpp',
             'workers/DedicatedWorkerMessagingProxy.h',
             'workers/DedicatedWorkerThread.cpp',
             'workers/DedicatedWorkerThread.h',
             'workers/InProcessWorkerBase.cpp',
             'workers/InProcessWorkerBase.h',
+            'workers/InProcessWorkerGlobalScopeProxy.h',
+            'workers/InProcessWorkerMessagingProxy.cpp',
+            'workers/InProcessWorkerMessagingProxy.h',
             'workers/MainThreadWorkletGlobalScope.h',
             'workers/SharedWorker.cpp',
             'workers/SharedWorker.h',
@@ -2252,16 +2257,11 @@
             'workers/WorkerEventQueue.h',
             'workers/WorkerGlobalScope.cpp',
             'workers/WorkerGlobalScope.h',
-            'workers/WorkerGlobalScopeProxy.h',
-            'workers/WorkerGlobalScopeProxyProvider.cpp',
-            'workers/WorkerGlobalScopeProxyProvider.h',
             'workers/WorkerInspectorProxy.cpp',
             'workers/WorkerInspectorProxy.h',
             'workers/WorkerLoaderProxy.cpp',
             'workers/WorkerLoaderProxy.h',
             'workers/WorkerLocation.h',
-            'workers/WorkerMessagingProxy.cpp',
-            'workers/WorkerMessagingProxy.h',
             'workers/WorkerNavigator.cpp',
             'workers/WorkerNavigator.h',
             'workers/WorkerObjectProxy.cpp',
diff --git a/third_party/WebKit/Source/core/frame/FrameConsole.cpp b/third_party/WebKit/Source/core/frame/FrameConsole.cpp
index 6229144..892316d 100644
--- a/third_party/WebKit/Source/core/frame/FrameConsole.cpp
+++ b/third_party/WebKit/Source/core/frame/FrameConsole.cpp
@@ -36,7 +36,6 @@
 #include "core/inspector/InspectorConsoleInstrumentation.h"
 #include "core/page/ChromeClient.h"
 #include "core/page/Page.h"
-#include "core/workers/WorkerGlobalScopeProxy.h"
 #include "platform/network/ResourceError.h"
 #include "platform/network/ResourceResponse.h"
 #include "wtf/text/StringBuilder.h"
diff --git a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxyProvider.cpp b/third_party/WebKit/Source/core/workers/DedicatedWorkerGlobalScopeProxyProvider.cpp
similarity index 72%
rename from third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxyProvider.cpp
rename to third_party/WebKit/Source/core/workers/DedicatedWorkerGlobalScopeProxyProvider.cpp
index 6a28ca8f..0e23be9 100644
--- a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxyProvider.cpp
+++ b/third_party/WebKit/Source/core/workers/DedicatedWorkerGlobalScopeProxyProvider.cpp
@@ -28,25 +28,25 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "core/workers/WorkerGlobalScopeProxyProvider.h"
+#include "core/workers/DedicatedWorkerGlobalScopeProxyProvider.h"
 
 #include "core/page/Page.h"
 
 namespace blink {
 
-WorkerGlobalScopeProxyProvider* WorkerGlobalScopeProxyProvider::from(Page& page)
+DedicatedWorkerGlobalScopeProxyProvider* DedicatedWorkerGlobalScopeProxyProvider::from(Page& page)
 {
-    return static_cast<WorkerGlobalScopeProxyProvider*>(Supplement<Page>::from(page, supplementName()));
+    return static_cast<DedicatedWorkerGlobalScopeProxyProvider*>(Supplement<Page>::from(page, supplementName()));
 }
 
-const char* WorkerGlobalScopeProxyProvider::supplementName()
+const char* DedicatedWorkerGlobalScopeProxyProvider::supplementName()
 {
-    return "WorkerGlobalScopeProxyProvider";
+    return "DedicatedWorkerGlobalScopeProxyProvider";
 }
 
-void provideWorkerGlobalScopeProxyProviderTo(Page& page, WorkerGlobalScopeProxyProvider* provider)
+void provideDedicatedWorkerGlobalScopeProxyProviderTo(Page& page, DedicatedWorkerGlobalScopeProxyProvider* provider)
 {
-    Supplement<Page>::provideTo(page, WorkerGlobalScopeProxyProvider::supplementName(), provider);
+    Supplement<Page>::provideTo(page, DedicatedWorkerGlobalScopeProxyProvider::supplementName(), provider);
 }
 
 } // namespace blink
diff --git a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxyProvider.h b/third_party/WebKit/Source/core/workers/DedicatedWorkerGlobalScopeProxyProvider.h
similarity index 72%
rename from third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxyProvider.h
rename to third_party/WebKit/Source/core/workers/DedicatedWorkerGlobalScopeProxyProvider.h
index a31cdb3..ad943bd 100644
--- a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxyProvider.h
+++ b/third_party/WebKit/Source/core/workers/DedicatedWorkerGlobalScopeProxyProvider.h
@@ -28,8 +28,8 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef WorkerGlobalScopeProxyProvider_h
-#define WorkerGlobalScopeProxyProvider_h
+#ifndef DedicatedWorkerGlobalScopeProxyProvider_h
+#define DedicatedWorkerGlobalScopeProxyProvider_h
 
 #include "core/CoreExport.h"
 #include "core/page/Page.h"
@@ -39,24 +39,24 @@
 
 namespace blink {
 
+class InProcessWorkerGlobalScopeProxy;
 class Page;
-class WorkerGlobalScopeProxy;
 class Worker;
 
-class WorkerGlobalScopeProxyProvider : public Supplement<Page> {
-    WTF_MAKE_NONCOPYABLE(WorkerGlobalScopeProxyProvider);
+class DedicatedWorkerGlobalScopeProxyProvider : public Supplement<Page> {
+    WTF_MAKE_NONCOPYABLE(DedicatedWorkerGlobalScopeProxyProvider);
 public:
-    WorkerGlobalScopeProxyProvider() { }
-    virtual ~WorkerGlobalScopeProxyProvider() { }
+    DedicatedWorkerGlobalScopeProxyProvider() { }
+    virtual ~DedicatedWorkerGlobalScopeProxyProvider() { }
 
-    virtual WorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(Worker*) = 0;
+    virtual InProcessWorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(Worker*) = 0;
 
-    static WorkerGlobalScopeProxyProvider* from(Page&);
+    static DedicatedWorkerGlobalScopeProxyProvider* from(Page&);
     static const char* supplementName();
 };
 
-CORE_EXPORT void provideWorkerGlobalScopeProxyProviderTo(Page&, WorkerGlobalScopeProxyProvider*);
+CORE_EXPORT void provideDedicatedWorkerGlobalScopeProxyProviderTo(Page&, DedicatedWorkerGlobalScopeProxyProvider*);
 
 } // namespace blink
 
-#endif // WorkerGlobalScopeProxyProvider_h
+#endif // DedicatedWorkerGlobalScopeProxyProvider_h
diff --git a/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.cpp b/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.cpp
index 37457c7..8df33e8f 100644
--- a/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.cpp
+++ b/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.cpp
@@ -10,7 +10,7 @@
 namespace blink {
 
 DedicatedWorkerMessagingProxy::DedicatedWorkerMessagingProxy(InProcessWorkerBase* workerObject, WorkerClients* workerClients)
-    : WorkerMessagingProxy(workerObject, workerClients)
+    : InProcessWorkerMessagingProxy(workerObject, workerClients)
 {
 }
 
diff --git a/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.h b/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.h
index ff081a8..941e069 100644
--- a/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.h
+++ b/third_party/WebKit/Source/core/workers/DedicatedWorkerMessagingProxy.h
@@ -6,13 +6,13 @@
 #define DedicatedWorkerMessagingProxy_h
 
 #include "core/CoreExport.h"
-#include "core/workers/WorkerMessagingProxy.h"
+#include "core/workers/InProcessWorkerMessagingProxy.h"
 
 namespace blink {
 
-class CORE_EXPORT DedicatedWorkerMessagingProxy final : public WorkerMessagingProxy {
+class CORE_EXPORT DedicatedWorkerMessagingProxy final : public InProcessWorkerMessagingProxy {
     WTF_MAKE_NONCOPYABLE(DedicatedWorkerMessagingProxy);
-    USING_FAST_MALLOC(WorkerMessagingProxy);
+    USING_FAST_MALLOC(DedicatedWorkerMessagingProxy);
 public:
     DedicatedWorkerMessagingProxy(InProcessWorkerBase*, WorkerClients*);
     ~DedicatedWorkerMessagingProxy() override;
diff --git a/third_party/WebKit/Source/core/workers/InProcessWorkerBase.cpp b/third_party/WebKit/Source/core/workers/InProcessWorkerBase.cpp
index 51c02e75..8ac1d7ad 100644
--- a/third_party/WebKit/Source/core/workers/InProcessWorkerBase.cpp
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerBase.cpp
@@ -10,7 +10,7 @@
 #include "core/frame/LocalDOMWindow.h"
 #include "core/frame/csp/ContentSecurityPolicy.h"
 #include "core/inspector/InspectorInstrumentation.h"
-#include "core/workers/WorkerGlobalScopeProxy.h"
+#include "core/workers/InProcessWorkerGlobalScopeProxy.h"
 #include "core/workers/WorkerScriptLoader.h"
 #include "core/workers/WorkerThread.h"
 #include "platform/network/ContentSecurityPolicyResponseHeaders.h"
@@ -59,7 +59,7 @@
         bind(&InProcessWorkerBase::onResponse, this),
         bind(&InProcessWorkerBase::onFinished, this));
 
-    m_contextProxy = createWorkerGlobalScopeProxy(context);
+    m_contextProxy = createInProcessWorkerGlobalScopeProxy(context);
 
     return true;
 }
diff --git a/third_party/WebKit/Source/core/workers/InProcessWorkerBase.h b/third_party/WebKit/Source/core/workers/InProcessWorkerBase.h
index 96e29ad..a7dc13ad 100644
--- a/third_party/WebKit/Source/core/workers/InProcessWorkerBase.h
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerBase.h
@@ -22,7 +22,7 @@
 
 class ExceptionState;
 class ExecutionContext;
-class WorkerGlobalScopeProxy;
+class InProcessWorkerGlobalScopeProxy;
 class WorkerScriptLoader;
 
 // Base class for workers that operate in the same process as the document that
@@ -52,7 +52,7 @@
 
     // Creates a proxy to allow communicating with the worker's global scope. InProcessWorkerBase does not take ownership of the
     // created proxy. The proxy is expected to manage its own lifetime, and delete itself in response to terminateWorkerGlobalScope().
-    virtual WorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(ExecutionContext*) = 0;
+    virtual InProcessWorkerGlobalScopeProxy* createInProcessWorkerGlobalScopeProxy(ExecutionContext*) = 0;
 
 private:
     // Callbacks for m_scriptLoader.
@@ -61,7 +61,7 @@
 
     RefPtr<WorkerScriptLoader> m_scriptLoader;
     Member<ContentSecurityPolicy> m_contentSecurityPolicy;
-    WorkerGlobalScopeProxy* m_contextProxy; // The proxy outlives the worker to perform thread shutdown.
+    InProcessWorkerGlobalScopeProxy* m_contextProxy; // The proxy outlives the worker to perform thread shutdown.
 };
 
 } // namespace blink
diff --git a/third_party/WebKit/Source/core/workers/WorkerMessagingProxy.cpp b/third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.cpp
similarity index 83%
rename from third_party/WebKit/Source/core/workers/WorkerMessagingProxy.cpp
rename to third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.cpp
index 2cb6690..597ff9c 100644
--- a/third_party/WebKit/Source/core/workers/WorkerMessagingProxy.cpp
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.cpp
@@ -26,7 +26,7 @@
  */
 
 
-#include "core/workers/WorkerMessagingProxy.h"
+#include "core/workers/InProcessWorkerMessagingProxy.h"
 
 #include "bindings/core/v8/V8GCController.h"
 #include "core/dom/CrossThreadTask.h"
@@ -71,7 +71,7 @@
 
 } // namespace
 
-WorkerMessagingProxy::WorkerMessagingProxy(InProcessWorkerBase* workerObject, WorkerClients* workerClients)
+InProcessWorkerMessagingProxy::InProcessWorkerMessagingProxy(InProcessWorkerBase* workerObject, WorkerClients* workerClients)
     : m_executionContext(workerObject->getExecutionContext())
     , m_workerObjectProxy(WorkerObjectProxy::create(this))
     , m_workerObject(workerObject)
@@ -87,7 +87,7 @@
         || (m_executionContext->isWorkerGlobalScope() && toWorkerGlobalScope(m_executionContext.get())->thread()->isCurrentThread()));
 }
 
-WorkerMessagingProxy::~WorkerMessagingProxy()
+InProcessWorkerMessagingProxy::~InProcessWorkerMessagingProxy()
 {
     ASSERT(!m_workerObject);
     ASSERT((m_executionContext->isDocument() && isMainThread())
@@ -96,7 +96,7 @@
         m_loaderProxy->detachProvider(this);
 }
 
-void WorkerMessagingProxy::startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode)
+void InProcessWorkerMessagingProxy::startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode)
 {
     // FIXME: This need to be revisited when we support nested worker one day
     ASSERT(m_executionContext->isDocument());
@@ -121,7 +121,7 @@
     m_workerInspectorProxy->workerThreadCreated(document, m_workerThread.get(), scriptURL);
 }
 
-void WorkerMessagingProxy::postMessageToWorkerObject(PassRefPtr<SerializedScriptValue> message, PassOwnPtr<MessagePortChannelArray> channels)
+void InProcessWorkerMessagingProxy::postMessageToWorkerObject(PassRefPtr<SerializedScriptValue> message, PassOwnPtr<MessagePortChannelArray> channels)
 {
     if (!m_workerObject || m_askedToTerminate)
         return;
@@ -130,7 +130,7 @@
     m_workerObject->dispatchEvent(MessageEvent::create(ports, message));
 }
 
-void WorkerMessagingProxy::postMessageToWorkerGlobalScope(PassRefPtr<SerializedScriptValue> message, PassOwnPtr<MessagePortChannelArray> channels)
+void InProcessWorkerMessagingProxy::postMessageToWorkerGlobalScope(PassRefPtr<SerializedScriptValue> message, PassOwnPtr<MessagePortChannelArray> channels)
 {
     if (m_askedToTerminate)
         return;
@@ -144,7 +144,7 @@
     }
 }
 
-bool WorkerMessagingProxy::postTaskToWorkerGlobalScope(PassOwnPtr<ExecutionContextTask> task)
+bool InProcessWorkerMessagingProxy::postTaskToWorkerGlobalScope(PassOwnPtr<ExecutionContextTask> task)
 {
     if (m_askedToTerminate)
         return false;
@@ -154,14 +154,14 @@
     return true;
 }
 
-void WorkerMessagingProxy::postTaskToLoader(PassOwnPtr<ExecutionContextTask> task)
+void InProcessWorkerMessagingProxy::postTaskToLoader(PassOwnPtr<ExecutionContextTask> task)
 {
     // FIXME: In case of nested workers, this should go directly to the root Document context.
     ASSERT(m_executionContext->isDocument());
     m_executionContext->postTask(BLINK_FROM_HERE, task);
 }
 
-void WorkerMessagingProxy::reportException(const String& errorMessage, int lineNumber, int columnNumber, const String& sourceURL, int exceptionId)
+void InProcessWorkerMessagingProxy::reportException(const String& errorMessage, int lineNumber, int columnNumber, const String& sourceURL, int exceptionId)
 {
     if (!m_workerObject)
         return;
@@ -174,7 +174,7 @@
     postTaskToWorkerGlobalScope(createCrossThreadTask(&processExceptionOnWorkerGlobalScope, exceptionId, dispatchResult != DispatchEventResult::NotCanceled));
 }
 
-void WorkerMessagingProxy::reportConsoleMessage(MessageSource source, MessageLevel level, const String& message, int lineNumber, const String& sourceURL)
+void InProcessWorkerMessagingProxy::reportConsoleMessage(MessageSource source, MessageLevel level, const String& message, int lineNumber, const String& sourceURL)
 {
     if (m_askedToTerminate)
         return;
@@ -190,7 +190,7 @@
     frame->console().addMessage(consoleMessage);
 }
 
-void WorkerMessagingProxy::workerThreadCreated()
+void InProcessWorkerMessagingProxy::workerThreadCreated()
 {
     ASSERT(!m_askedToTerminate);
     ASSERT(m_workerThread);
@@ -204,17 +204,17 @@
     m_queuedEarlyTasks.clear();
 }
 
-void WorkerMessagingProxy::workerObjectDestroyed()
+void InProcessWorkerMessagingProxy::workerObjectDestroyed()
 {
     // workerObjectDestroyed() is called in InProcessWorkerBase's destructor.
     // Thus it should be guaranteed that a weak pointer m_workerObject has been cleared
     // before this method gets called.
     ASSERT(!m_workerObject);
 
-    m_executionContext->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::workerObjectDestroyedInternal, this));
+    m_executionContext->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::workerObjectDestroyedInternal, this));
 }
 
-void WorkerMessagingProxy::workerObjectDestroyedInternal()
+void InProcessWorkerMessagingProxy::workerObjectDestroyedInternal()
 {
     m_mayBeDestroyed = true;
     if (m_workerThread)
@@ -223,7 +223,7 @@
         workerThreadTerminated();
 }
 
-void WorkerMessagingProxy::workerThreadTerminated()
+void InProcessWorkerMessagingProxy::workerThreadTerminated()
 {
     // This method is always the last to be performed, so the proxy is not needed for communication
     // in either side any more. However, the Worker object may still exist, and it assumes that the proxy exists, too.
@@ -234,7 +234,7 @@
         delete this;
 }
 
-void WorkerMessagingProxy::terminateWorkerGlobalScope()
+void InProcessWorkerMessagingProxy::terminateWorkerGlobalScope()
 {
     if (m_askedToTerminate)
         return;
@@ -246,19 +246,19 @@
     terminateInternally();
 }
 
-void WorkerMessagingProxy::postMessageToPageInspector(const String& message)
+void InProcessWorkerMessagingProxy::postMessageToPageInspector(const String& message)
 {
     if (m_workerInspectorProxy)
         m_workerInspectorProxy->dispatchMessageFromWorker(message);
 }
 
-void WorkerMessagingProxy::postWorkerConsoleAgentEnabled()
+void InProcessWorkerMessagingProxy::postWorkerConsoleAgentEnabled()
 {
     if (m_workerInspectorProxy)
         m_workerInspectorProxy->workerConsoleAgentEnabled();
 }
 
-void WorkerMessagingProxy::confirmMessageFromWorkerObject(bool hasPendingActivity)
+void InProcessWorkerMessagingProxy::confirmMessageFromWorkerObject(bool hasPendingActivity)
 {
     if (!m_askedToTerminate) {
         ASSERT(m_unconfirmedMessageCount);
@@ -267,17 +267,17 @@
     reportPendingActivity(hasPendingActivity);
 }
 
-void WorkerMessagingProxy::reportPendingActivity(bool hasPendingActivity)
+void InProcessWorkerMessagingProxy::reportPendingActivity(bool hasPendingActivity)
 {
     m_workerThreadHadPendingActivity = hasPendingActivity;
 }
 
-bool WorkerMessagingProxy::hasPendingActivity() const
+bool InProcessWorkerMessagingProxy::hasPendingActivity() const
 {
     return (m_unconfirmedMessageCount || m_workerThreadHadPendingActivity) && !m_askedToTerminate;
 }
 
-void WorkerMessagingProxy::terminateInternally()
+void InProcessWorkerMessagingProxy::terminateInternally()
 {
     m_workerInspectorProxy->workerThreadTerminated();
 
diff --git a/third_party/WebKit/Source/core/workers/Worker.cpp b/third_party/WebKit/Source/core/workers/Worker.cpp
index 30f034d..a407d094 100644
--- a/third_party/WebKit/Source/core/workers/Worker.cpp
+++ b/third_party/WebKit/Source/core/workers/Worker.cpp
@@ -8,8 +8,8 @@
 #include "core/dom/Document.h"
 #include "core/dom/ExceptionCode.h"
 #include "core/frame/UseCounter.h"
-#include "core/workers/WorkerGlobalScopeProxy.h"
-#include "core/workers/WorkerGlobalScopeProxyProvider.h"
+#include "core/workers/DedicatedWorkerGlobalScopeProxyProvider.h"
+#include "core/workers/InProcessWorkerGlobalScopeProxy.h"
 
 namespace blink {
 
@@ -43,10 +43,10 @@
     return EventTargetNames::Worker;
 }
 
-WorkerGlobalScopeProxy* Worker::createWorkerGlobalScopeProxy(ExecutionContext* context)
+InProcessWorkerGlobalScopeProxy* Worker::createInProcessWorkerGlobalScopeProxy(ExecutionContext* context)
 {
     Document* document = toDocument(context);
-    WorkerGlobalScopeProxyProvider* proxyProvider = WorkerGlobalScopeProxyProvider::from(*document->page());
+    DedicatedWorkerGlobalScopeProxyProvider* proxyProvider = DedicatedWorkerGlobalScopeProxyProvider::from(*document->page());
     ASSERT(proxyProvider);
     return proxyProvider->createWorkerGlobalScopeProxy(this);
 }
diff --git a/third_party/WebKit/Source/core/workers/Worker.h b/third_party/WebKit/Source/core/workers/Worker.h
index 2dbf303b..f593886c 100644
--- a/third_party/WebKit/Source/core/workers/Worker.h
+++ b/third_party/WebKit/Source/core/workers/Worker.h
@@ -11,7 +11,7 @@
 
 class ExceptionState;
 class ExecutionContext;
-class WorkerGlobalScopeProxy;
+class InProcessWorkerGlobalScopeProxy;
 
 class CORE_EXPORT Worker final : public InProcessWorkerBase {
     DEFINE_WRAPPERTYPEINFO();
@@ -22,7 +22,7 @@
 protected:
     explicit Worker(ExecutionContext*);
 
-    WorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(ExecutionContext*) override;
+    InProcessWorkerGlobalScopeProxy* createInProcessWorkerGlobalScopeProxy(ExecutionContext*) override;
     const AtomicString& interfaceName() const override;
 };
 
diff --git a/third_party/WebKit/Source/core/workers/WorkerObjectProxy.cpp b/third_party/WebKit/Source/core/workers/WorkerObjectProxy.cpp
index b25788c..3f10dca 100644
--- a/third_party/WebKit/Source/core/workers/WorkerObjectProxy.cpp
+++ b/third_party/WebKit/Source/core/workers/WorkerObjectProxy.cpp
@@ -35,12 +35,12 @@
 #include "core/dom/Document.h"
 #include "core/dom/ExecutionContext.h"
 #include "core/inspector/ConsoleMessage.h"
-#include "core/workers/WorkerMessagingProxy.h"
+#include "core/workers/InProcessWorkerMessagingProxy.h"
 #include "wtf/Functional.h"
 
 namespace blink {
 
-PassOwnPtr<WorkerObjectProxy> WorkerObjectProxy::create(WorkerMessagingProxy* messagingProxy)
+PassOwnPtr<WorkerObjectProxy> WorkerObjectProxy::create(InProcessWorkerMessagingProxy* messagingProxy)
 {
     ASSERT(messagingProxy);
     return adoptPtr(new WorkerObjectProxy(messagingProxy));
@@ -48,7 +48,7 @@
 
 void WorkerObjectProxy::postMessageToWorkerObject(PassRefPtr<SerializedScriptValue> message, PassOwnPtr<MessagePortChannelArray> channels)
 {
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::postMessageToWorkerObject, m_messagingProxy, message, channels));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::postMessageToWorkerObject, m_messagingProxy, message, channels));
 }
 
 void WorkerObjectProxy::postTaskToMainExecutionContext(PassOwnPtr<ExecutionContextTask> task)
@@ -58,50 +58,50 @@
 
 void WorkerObjectProxy::confirmMessageFromWorkerObject(bool hasPendingActivity)
 {
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::confirmMessageFromWorkerObject, m_messagingProxy, hasPendingActivity));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::confirmMessageFromWorkerObject, m_messagingProxy, hasPendingActivity));
 }
 
 void WorkerObjectProxy::reportPendingActivity(bool hasPendingActivity)
 {
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::reportPendingActivity, m_messagingProxy, hasPendingActivity));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::reportPendingActivity, m_messagingProxy, hasPendingActivity));
 }
 
 void WorkerObjectProxy::reportException(const String& errorMessage, int lineNumber, int columnNumber, const String& sourceURL, int exceptionId)
 {
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::reportException, m_messagingProxy, errorMessage, lineNumber, columnNumber, sourceURL, exceptionId));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::reportException, m_messagingProxy, errorMessage, lineNumber, columnNumber, sourceURL, exceptionId));
 }
 
 void WorkerObjectProxy::reportConsoleMessage(ConsoleMessage* consoleMessage)
 {
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::reportConsoleMessage, m_messagingProxy, consoleMessage->source(), consoleMessage->level(), consoleMessage->message(), consoleMessage->lineNumber(), consoleMessage->url()));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::reportConsoleMessage, m_messagingProxy, consoleMessage->source(), consoleMessage->level(), consoleMessage->message(), consoleMessage->lineNumber(), consoleMessage->url()));
 }
 
 void WorkerObjectProxy::postMessageToPageInspector(const String& message)
 {
     ExecutionContext* context = getExecutionContext();
     if (context->isDocument())
-        toDocument(context)->postInspectorTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::postMessageToPageInspector, m_messagingProxy, message));
+        toDocument(context)->postInspectorTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::postMessageToPageInspector, m_messagingProxy, message));
 }
 
 void WorkerObjectProxy::postWorkerConsoleAgentEnabled()
 {
     ExecutionContext* context = getExecutionContext();
     if (context->isDocument())
-        toDocument(context)->postInspectorTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::postWorkerConsoleAgentEnabled, m_messagingProxy));
+        toDocument(context)->postInspectorTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::postWorkerConsoleAgentEnabled, m_messagingProxy));
 }
 
 void WorkerObjectProxy::workerGlobalScopeClosed()
 {
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::terminateWorkerGlobalScope, m_messagingProxy));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::terminateWorkerGlobalScope, m_messagingProxy));
 }
 
 void WorkerObjectProxy::workerThreadTerminated()
 {
     // This will terminate the MessagingProxy.
-    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&WorkerMessagingProxy::workerThreadTerminated, m_messagingProxy));
+    getExecutionContext()->postTask(BLINK_FROM_HERE, createCrossThreadTask(&InProcessWorkerMessagingProxy::workerThreadTerminated, m_messagingProxy));
 }
 
-WorkerObjectProxy::WorkerObjectProxy(WorkerMessagingProxy* messagingProxy)
+WorkerObjectProxy::WorkerObjectProxy(InProcessWorkerMessagingProxy* messagingProxy)
     : m_messagingProxy(messagingProxy)
 {
 }
diff --git a/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.cpp b/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.cpp
index 759dc94..3eefc6a 100644
--- a/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.cpp
+++ b/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.cpp
@@ -42,7 +42,7 @@
     return EventTargetNames::CompositorWorker;
 }
 
-WorkerGlobalScopeProxy* CompositorWorker::createWorkerGlobalScopeProxy(ExecutionContext* worker)
+InProcessWorkerGlobalScopeProxy* CompositorWorker::createInProcessWorkerGlobalScopeProxy(ExecutionContext* worker)
 {
     ASSERT(getExecutionContext()->isDocument());
     return new CompositorWorkerMessagingProxy(this);
diff --git a/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.h b/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.h
index 9a8f05a..32666cc 100644
--- a/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.h
+++ b/third_party/WebKit/Source/modules/compositorworker/CompositorWorker.h
@@ -14,7 +14,7 @@
 
 class ExceptionState;
 class ExecutionContext;
-class WorkerGlobalScopeProxy;
+class InProcessWorkerGlobalScopeProxy;
 
 class MODULES_EXPORT CompositorWorker final : public InProcessWorkerBase {
     DEFINE_WRAPPERTYPEINFO();
@@ -23,7 +23,7 @@
     ~CompositorWorker() override;
 
     const AtomicString& interfaceName() const override;
-    WorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(ExecutionContext*) override;
+    InProcessWorkerGlobalScopeProxy* createInProcessWorkerGlobalScopeProxy(ExecutionContext*) override;
 
 private:
     explicit CompositorWorker(ExecutionContext*);
diff --git a/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.cpp b/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.cpp
index 041ba09..676e3849 100644
--- a/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.cpp
+++ b/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.cpp
@@ -10,7 +10,7 @@
 namespace blink {
 
 CompositorWorkerMessagingProxy::CompositorWorkerMessagingProxy(InProcessWorkerBase* worker)
-    : WorkerMessagingProxy(worker, nullptr)
+    : InProcessWorkerMessagingProxy(worker, nullptr)
 {
 }
 
diff --git a/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.h b/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.h
index da72f7f1..4fd262d 100644
--- a/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.h
+++ b/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerMessagingProxy.h
@@ -5,12 +5,12 @@
 #ifndef CompositorWorkerMessagingProxy_h
 #define CompositorWorkerMessagingProxy_h
 
-#include "core/workers/WorkerMessagingProxy.h"
+#include "core/workers/InProcessWorkerMessagingProxy.h"
 #include "wtf/Allocator.h"
 
 namespace blink {
 
-class CompositorWorkerMessagingProxy final : public WorkerMessagingProxy {
+class CompositorWorkerMessagingProxy final : public InProcessWorkerMessagingProxy {
     USING_FAST_MALLOC(CompositorWorkerMessagingProxy);
 public:
     explicit CompositorWorkerMessagingProxy(InProcessWorkerBase*);
diff --git a/third_party/WebKit/Source/web/WorkerGlobalScopeProxyProviderImpl.cpp b/third_party/WebKit/Source/web/DedicatedWorkerGlobalScopeProxyProviderImpl.cpp
similarity index 94%
rename from third_party/WebKit/Source/web/WorkerGlobalScopeProxyProviderImpl.cpp
rename to third_party/WebKit/Source/web/DedicatedWorkerGlobalScopeProxyProviderImpl.cpp
index e99962e..c9a6881 100644
--- a/third_party/WebKit/Source/web/WorkerGlobalScopeProxyProviderImpl.cpp
+++ b/third_party/WebKit/Source/web/DedicatedWorkerGlobalScopeProxyProviderImpl.cpp
@@ -28,7 +28,7 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "web/WorkerGlobalScopeProxyProviderImpl.h"
+#include "web/DedicatedWorkerGlobalScopeProxyProviderImpl.h"
 
 #include "core/dom/Document.h"
 #include "core/workers/DedicatedWorkerMessagingProxy.h"
@@ -46,7 +46,7 @@
 
 namespace blink {
 
-WorkerGlobalScopeProxy* WorkerGlobalScopeProxyProviderImpl::createWorkerGlobalScopeProxy(Worker* worker)
+InProcessWorkerGlobalScopeProxy* DedicatedWorkerGlobalScopeProxyProviderImpl::createWorkerGlobalScopeProxy(Worker* worker)
 {
     if (worker->getExecutionContext()->isDocument()) {
         Document* document = toDocument(worker->getExecutionContext());
diff --git a/third_party/WebKit/Source/web/WorkerGlobalScopeProxyProviderImpl.h b/third_party/WebKit/Source/web/DedicatedWorkerGlobalScopeProxyProviderImpl.h
similarity index 63%
rename from third_party/WebKit/Source/web/WorkerGlobalScopeProxyProviderImpl.h
rename to third_party/WebKit/Source/web/DedicatedWorkerGlobalScopeProxyProviderImpl.h
index d24ef060..8ed01a7 100644
--- a/third_party/WebKit/Source/web/WorkerGlobalScopeProxyProviderImpl.h
+++ b/third_party/WebKit/Source/web/DedicatedWorkerGlobalScopeProxyProviderImpl.h
@@ -28,36 +28,35 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef WorkerGlobalScopeProxyProviderImpl_h
-#define WorkerGlobalScopeProxyProviderImpl_h
+#ifndef DedicatedWorkerGlobalScopeProxyProviderImpl_h
+#define DedicatedWorkerGlobalScopeProxyProviderImpl_h
 
-#include "core/workers/WorkerGlobalScopeProxyProvider.h"
+#include "core/workers/DedicatedWorkerGlobalScopeProxyProvider.h"
 #include "wtf/Noncopyable.h"
 #include "wtf/PassOwnPtr.h"
 
 namespace blink {
 
-class Worker;
-class WorkerGlobalScopeProxy;
-
-class WorkerGlobalScopeProxyProviderImpl final : public GarbageCollectedFinalized<WorkerGlobalScopeProxyProviderImpl>, public WorkerGlobalScopeProxyProvider {
-    USING_GARBAGE_COLLECTED_MIXIN(WorkerGlobalScopeProxyProviderImpl);
-    WTF_MAKE_NONCOPYABLE(WorkerGlobalScopeProxyProviderImpl);
+class DedicatedWorkerGlobalScopeProxyProviderImpl final
+    : public GarbageCollectedFinalized<DedicatedWorkerGlobalScopeProxyProviderImpl>
+    , public DedicatedWorkerGlobalScopeProxyProvider {
+    USING_GARBAGE_COLLECTED_MIXIN(DedicatedWorkerGlobalScopeProxyProviderImpl);
+    WTF_MAKE_NONCOPYABLE(DedicatedWorkerGlobalScopeProxyProviderImpl);
 public:
-    static WorkerGlobalScopeProxyProviderImpl* create()
+    static DedicatedWorkerGlobalScopeProxyProviderImpl* create()
     {
-        return new WorkerGlobalScopeProxyProviderImpl();
+        return new DedicatedWorkerGlobalScopeProxyProviderImpl();
     }
 
-    ~WorkerGlobalScopeProxyProviderImpl() override { }
-    WorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(Worker*) override;
+    ~DedicatedWorkerGlobalScopeProxyProviderImpl() override { }
+    InProcessWorkerGlobalScopeProxy* createWorkerGlobalScopeProxy(Worker*) override;
 
-    DEFINE_INLINE_VIRTUAL_TRACE() { WorkerGlobalScopeProxyProvider::trace(visitor); }
+    DEFINE_INLINE_VIRTUAL_TRACE() { DedicatedWorkerGlobalScopeProxyProvider::trace(visitor); }
 
 private:
-    WorkerGlobalScopeProxyProviderImpl() { }
+    DedicatedWorkerGlobalScopeProxyProviderImpl() { }
 };
 
 } // namespace blink
 
-#endif // WorkerGlobalScopeProxyProviderImpl_h
+#endif // DedicatedWorkerGlobalScopeProxyProviderImpl_h
diff --git a/third_party/WebKit/Source/web/WebViewImpl.cpp b/third_party/WebKit/Source/web/WebViewImpl.cpp
index 358c0455..c72781a 100644
--- a/third_party/WebKit/Source/web/WebViewImpl.cpp
+++ b/third_party/WebKit/Source/web/WebViewImpl.cpp
@@ -155,6 +155,7 @@
 #include "web/ContextFeaturesClientImpl.h"
 #include "web/ContextMenuAllowedScope.h"
 #include "web/DatabaseClientImpl.h"
+#include "web/DedicatedWorkerGlobalScopeProxyProviderImpl.h"
 #include "web/DevToolsEmulator.h"
 #include "web/FullscreenController.h"
 #include "web/InspectorOverlay.h"
@@ -174,7 +175,6 @@
 #include "web/WebPluginContainerImpl.h"
 #include "web/WebRemoteFrameImpl.h"
 #include "web/WebSettingsImpl.h"
-#include "web/WorkerGlobalScopeProxyProviderImpl.h"
 #include "wtf/CurrentTime.h"
 #include "wtf/RefPtr.h"
 #include "wtf/TemporaryChange.h"
@@ -459,7 +459,7 @@
 
     provideStorageQuotaClientTo(*m_page, StorageQuotaClientImpl::create());
     m_page->setValidationMessageClient(ValidationMessageClientImpl::create(*this));
-    provideWorkerGlobalScopeProxyProviderTo(*m_page, WorkerGlobalScopeProxyProviderImpl::create());
+    provideDedicatedWorkerGlobalScopeProxyProviderTo(*m_page, DedicatedWorkerGlobalScopeProxyProviderImpl::create());
     StorageNamespaceController::provideStorageNamespaceTo(*m_page, &m_storageClientImpl);
 
     if (m_client) {
diff --git a/third_party/WebKit/Source/web/web.gypi b/third_party/WebKit/Source/web/web.gypi
index a0d5546..52fd488 100644
--- a/third_party/WebKit/Source/web/web.gypi
+++ b/third_party/WebKit/Source/web/web.gypi
@@ -25,6 +25,8 @@
       'DatabaseClientImpl.h',
       'DateTimeChooserImpl.cpp',
       'DateTimeChooserImpl.h',
+      'DedicatedWorkerGlobalScopeProxyProviderImpl.cpp',
+      'DedicatedWorkerGlobalScopeProxyProviderImpl.h',
       'DevToolsEmulator.cpp',
       'DevToolsEmulator.h',
       'EditorClientImpl.cpp',
@@ -225,8 +227,6 @@
       'WebViewImpl.h',
       'WorkerContentSettingsClient.cpp',
       'WorkerContentSettingsClient.h',
-      'WorkerGlobalScopeProxyProviderImpl.cpp',
-      'WorkerGlobalScopeProxyProviderImpl.h',
       'default/WebRenderTheme.cpp',
       'linux/WebFontRendering.cpp',
       'mac/WebScrollbarTheme.mm',
diff --git a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxy.h b/third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h
similarity index 86%
rename from third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxy.h
rename to third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h
index 078a95b..419ae2d 100644
--- a/third_party/WebKit/Source/core/workers/WorkerGlobalScopeProxy.h
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerGlobalScopeProxy.h
@@ -28,8 +28,8 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef WorkerGlobalScopeProxy_h
-#define WorkerGlobalScopeProxy_h
+#ifndef InProcessWorkerGlobalScopeProxy_h
+#define InProcessWorkerGlobalScopeProxy_h
 
 #include "core/CoreExport.h"
 #include "core/dom/MessagePort.h"
@@ -41,11 +41,11 @@
 
 class KURL;
 
-// A proxy to talk to the worker global scope.
-class CORE_EXPORT WorkerGlobalScopeProxy {
-    USING_FAST_MALLOC(WorkerGlobalScopeProxy);
+// A proxy to talk to the in-process worker global scope.
+class CORE_EXPORT InProcessWorkerGlobalScopeProxy {
+    USING_FAST_MALLOC(InProcessWorkerGlobalScopeProxy);
 public:
-    virtual ~WorkerGlobalScopeProxy() { }
+    virtual ~InProcessWorkerGlobalScopeProxy() { }
 
     virtual void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode) = 0;
 
@@ -60,4 +60,4 @@
 
 } // namespace blink
 
-#endif // WorkerGlobalScopeProxy_h
+#endif // InProcessWorkerGlobalScopeProxy_h
diff --git a/third_party/WebKit/Source/core/workers/WorkerMessagingProxy.h b/third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
similarity index 87%
rename from third_party/WebKit/Source/core/workers/WorkerMessagingProxy.h
rename to third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
index 1810ccd..7498ce5 100644
--- a/third_party/WebKit/Source/core/workers/WorkerMessagingProxy.h
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
@@ -24,12 +24,12 @@
  *
  */
 
-#ifndef WorkerMessagingProxy_h
-#define WorkerMessagingProxy_h
+#ifndef InProcessWorkerMessagingProxy_h
+#define InProcessWorkerMessagingProxy_h
 
 #include "core/CoreExport.h"
 #include "core/dom/ExecutionContext.h"
-#include "core/workers/WorkerGlobalScopeProxy.h"
+#include "core/workers/InProcessWorkerGlobalScopeProxy.h"
 #include "core/workers/WorkerLoaderProxy.h"
 #include "wtf/Forward.h"
 #include "wtf/Noncopyable.h"
@@ -47,12 +47,15 @@
 class WorkerClients;
 class WorkerInspectorProxy;
 
-class CORE_EXPORT WorkerMessagingProxy
-    : public WorkerGlobalScopeProxy
+// TODO(nhiroki): "MessagingProxy" is not well-defined term among worker
+// components. Probably we should rename this to something more suitable.
+// (http://crbug.com/603785)
+class CORE_EXPORT InProcessWorkerMessagingProxy
+    : public InProcessWorkerGlobalScopeProxy
     , private WorkerLoaderProxyProvider {
-    WTF_MAKE_NONCOPYABLE(WorkerMessagingProxy);
+    WTF_MAKE_NONCOPYABLE(InProcessWorkerMessagingProxy);
 public:
     // Implementations of WorkerGlobalScopeProxy.
     // (Only use these methods in the worker object thread.)
     void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode) override;
     void terminateWorkerGlobalScope() override;
@@ -76,8 +79,8 @@
     ExecutionContext* getExecutionContext() const { return m_executionContext.get(); }
 
 protected:
-    WorkerMessagingProxy(InProcessWorkerBase*, WorkerClients*);
-    ~WorkerMessagingProxy() override;
+    InProcessWorkerMessagingProxy(InProcessWorkerBase*, WorkerClients*);
+    ~InProcessWorkerMessagingProxy() override;
 
     virtual PassOwnPtr<WorkerThread> createWorkerThread(double originTime) = 0;
 
@@ -115,4 +118,4 @@
 
 } // namespace blink
 
-#endif // WorkerMessagingProxy_h
+#endif // InProcessWorkerMessagingProxy_h
@@ -47,12 +47,15 @@
 public:
-    // Implementations of WorkerGlobalScopeProxy.
+    // Implementations of InProcessWorkerGlobalScopeProxy.
     // (Only use these methods in the worker object thread.)
     void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode) override;
diff --git a/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h b/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
index eb888d84..ae4445b 100644
--- a/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
+++ b/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
@@ -43,19 +43,19 @@
 class ConsoleMessage;
 class ExecutionContext;
 class ExecutionContextTask;
-class WorkerMessagingProxy;
+class InProcessWorkerMessagingProxy;
 
 // A proxy to talk to the worker object. This object is created on the
 // worker object thread (i.e. usually the main thread), passed on to
 // the worker thread, and used just to proxy messages to the
 // WorkerMessagingProxy on the worker object thread.
 //
 // Used only by in-process workers (DedicatedWorker and CompositorWorker.)
 class CORE_EXPORT WorkerObjectProxy : public WorkerReportingProxy {
     USING_FAST_MALLOC(WorkerObjectProxy);
     WTF_MAKE_NONCOPYABLE(WorkerObjectProxy);
 public:
-    static PassOwnPtr<WorkerObjectProxy> create(WorkerMessagingProxy*);
+    static PassOwnPtr<WorkerObjectProxy> create(InProcessWorkerMessagingProxy*);
     ~WorkerObjectProxy() override { }
 
     void postMessageToWorkerObject(PassRefPtr<SerializedScriptValue>, PassOwnPtr<MessagePortChannelArray>);
@@ -75,12 +75,12 @@
     void willDestroyWorkerGlobalScope() override { }
 
 protected:
-    WorkerObjectProxy(WorkerMessagingProxy*);
+    WorkerObjectProxy(InProcessWorkerMessagingProxy*);
     virtual ExecutionContext* getExecutionContext();
 
 private:
     // This object always outlives this proxy.
-    WorkerMessagingProxy* m_messagingProxy;
+    InProcessWorkerMessagingProxy* m_messagingProxy;
 };
 
 } // namespace blink
@@ -43,19 +43,19 @@
 // worker object thread (i.e. usually the main thread), passed on to
 // the worker thread, and used just to proxy messages to the
-// WorkerMessagingProxy on the worker object thread.
+// InProcessWorkerMessagingProxy on the worker object thread.
 //
 // Used only by in-process workers (DedicatedWorker and CompositorWorker.)